@@ -51,22 +51,38 @@ class LoadDataKline:
         unix_max = unix_max or unix_end
         unix_min = unix_min or unix_end
         #print(unix_start, unix_end, unix_max, unix_max)
+        if abs((unix_max-unix_min)/unix_delta) > 100:
+            if unix_min >= unix_start:
+                unix_temp = unix_min
+                pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
+                for _ in pbar:
+                    status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
+                    if status is False:
+                        break
+                    pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
+                    unix_temp = result[0][0]
 
-        if unix_min >= unix_start:
-            unix_temp = unix_min
-            pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
-            for _ in pbar:
-                status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
-                if status is False:
-                    break
-                pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
-                unix_temp = result[0][0]
+            if unix_max >= unix_end:
+                unix_temp = unix_max
+                pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
+                for _ in pbar:
+                    status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
+                    if status is False:
+                        break
+                    unix_temp = result[-1][0]
+        else:
+            if unix_min >= unix_start:
+                unix_temp = unix_min
+                for _ in range(unix_min, unix_start, -unix_delta):
+                    status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
+                    if status is False:
+                        break
+                    unix_temp = result[0][0]
 
-        if unix_max >= unix_end:
-            unix_temp = unix_max
-            pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
-            for _ in pbar:
-                status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
-                if status is False:
-                    break
-                unix_temp = result[-1][0]
+            if unix_max >= unix_end:
+                unix_temp = unix_max
+                for _ in range(unix_max, unix_end, unix_delta):
+                    status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
+                    if status is False:
+                        break
+                    unix_temp = result[-1][0]
